@@ -21,6 +21,7 @@
 #include <glib-object.h>
 
 #include "e-accounts-window-editors.h"
+#include "e-collection-wizard-page.h"
 #include "e-webdav-browser-page.h"
 
 /* Module Entry Points */
@@ -31,6 +32,7 @@ G_MODULE_EXPORT void
 e_module_load (GTypeModule *type_module)
 {
 	e_accounts_window_editors_type_register (type_module);
+	e_collection_wizard_page_type_register (type_module);
 	e_webdav_browser_page_type_register (type_module);
 }
 
